==> opennms-vmware-19.0.0-20160602.005709-59-sources.jar: org/opennms/netmgt/collectd/vmware/cim/VmwareCimCollectionAttributeType.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collectd.vmware.cim;

import org.opennms.netmgt.collection.api.AttributeGroupType;
import org.opennms.netmgt.collection.api.CollectionAttribute;
import org.opennms.netmgt.collection.api.Persister;
import org.opennms.netmgt.collection.support.AbstractCollectionAttributeType;
import org.opennms.netmgt.config.vmware.cim.Attrib;

public class VmwareCimCollectionAttributeType extends AbstractCollectionAttributeType {
    private final Attrib m_attribute;

    public VmwareCimCollectionAttributeType(final Attrib attribute, final AttributeGroupType groupType) {
        super(groupType);
        m_attribute = attribute;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void storeAttribute(final CollectionAttribute attribute, final Persister persister) {
        if ("string".equalsIgnoreCase(m_attribute.getType())) {
            persister.persistStringAttribute(attribute);
        } else {
            persister.persistNumericAttribute(attribute);
        }
    }

    @Override
    public String getName() {
        return m_attribute.getAlias();
    }

    @Override
    public String getType() {
        return m_attribute.getType();
    }
}

==> opennms-vmware-20.0.0-20170215.044358-83-sources.jar: org/opennms/netmgt/collectd/vmware/cim/VmwareCimCollectionAttributeType.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2010-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collectd.vmware.cim;

import org.opennms.netmgt.collection.api.AttributeGroupType;
import org.opennms.netmgt.collection.api.AttributeType;
import org.opennms.netmgt.collection.api.CollectionAttribute;
import org.opennms.netmgt.collection.api.Persister;
import org.opennms.netmgt.collection.support.AbstractCollectionAttributeType;
import org.opennms.netmgt.config.vmware.cim.Attrib;

public class VmwareCimCollectionAttributeType extends AbstractCollectionAttributeType {
    private final Attrib m_attribute;

    public VmwareCimCollectionAttributeType(final Attrib attribute, final AttributeGroupType groupType) {
        super(groupType);
        m_attribute = attribute;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void storeAttribute(final CollectionAttribute attribute, final Persister persister) {
        if (m_attribute.getType().isNumeric()) {
            persister.persistNumericAttribute(attribute);
        } else {
            persister.persistStringAttribute(attribute);
        }
    }

    @Override
    public String getName() {
        return m_attribute.getAlias();
    }

    @Override
    public AttributeType getType() {
        return m_attribute.getType();
    }
}
